# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Anonymous = object
Any = object
BoundMethodWeakref = object
DispatcherError = object
Parameter = object
_call = dummy_function
_cleanupConnections = dummy_function
_removeReceiver = dummy_function
_removeSender = dummy_function
connect = dummy_function
connections = dict()
disconnect = dummy_function
safeRef = dummy_function
send = dummy_function
senders = dict()



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Buffer = object
DialogResults = object
EditWindow = object
Editor = object
EditorFrame = object
EditorNotebook = object
EditorNotebookFrame = object
EditorShellNotebook = object
EditorShellNotebookFrame = object
Shell = object
directory = dummy_function
fileDialog = dummy_function
messageDialog = dummy_function
openMultiple = dummy_function
openSingle = dummy_function
saveSingle = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


HTTPError = object
URLError = object
download_file = dummy_function
download_pip = dummy_function
download_urllib = dummy_function
download_wget = dummy_function
get_docs_demo_url = dummy_function
get_save_path = dummy_function
main = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Buffer = object
DISPLAY_TEXT = ''
GROUPING_END = 0
GROUPING_MASK = 0
GROUPING_MIDDLE = 0
GROUPING_SELECTING = 0
GROUPING_START = 0
GROUPING_START_FOLDED = 0
HELP_TEXT = ''
INPUT_END = 0
INPUT_MASK = 0
INPUT_MIDDLE = 0
INPUT_READLINE = 0
INPUT_START = 0
INPUT_START_FOLDED = 0
IO_ANY_START_MASK = 0
IO_END_MASK = 0
IO_MASK = 0
IO_MIDDLE_MASK = 0
IO_SELECTING = 0
IO_START_FOLDED_MASK = 0
IO_START_MASK = 0
NAVKEYS = tuple()
OUTPUT_BG = 0
OUTPUT_END = 0
OUTPUT_MASK = 0
OUTPUT_MIDDLE = 0
OUTPUT_START = 0
OUTPUT_START_FOLDED = 0
PRINT_UPDATE_MAX_TIME = 0
PseudoFileErr = object
PseudoFileIn = object
PseudoFileOut = object
READLINE_BG = 0
SlicesShell = object
SlicesShellFacade = object
SlicesShellFrame = object
VERSION = ''
cd = dummy_function
cmp_to_key = dummy_function
groupingStartText = ''
inputStartText = ''
ls = dummy_function
magic = dummy_function
outputStartText = ''
pwd = dummy_function
pyslicesFormatHeaderText = []
sx = dummy_function
testForContinuations = dummy_function
tutorialText = ''
usrBinEnvPythonText = ''



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


Calltip = object
Crust = object
CrustFrame = object
DispatcherListing = object
Display = object
Filling = object
SessionListing = object
Shell = object
VERSION = ''



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


DEFAULT_IMGNAME = ''
DEFAULT_MASKCLR = None
app = None
b64encode = dummy_function
convert = dummy_function
img2py = dummy_function
main = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


App = object
COMMONTYPES = []
DOCTYPES = tuple()
Filling = object
FillingFrame = object
FillingText = object
FillingTree = object
SIMPLETYPES = []



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


getColourInfoList = dummy_function
getColourList = dummy_function
updateColourDB = dummy_function



# Based on wxPython
# Copyright: (c) 2018 by Total Control Software
# License:   wxWindows License


def dummy_function(*args, **kwargs):
	return 0


EVT_ETC_LAYOUT_NEEDED = object
ExpandoTextCtrl = object
wxEVT_ETC_LAYOUT_NEEDED = 0
